/**
* vue-transitions
* https://www.npmjs.com/package/vue-transitions
* (c) 2017 Jason Buss
* @license MIT
* 
**/"use strict";

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

function buildExpandTransition() {
  "use strict";

  var defaultDuration = 250;

  function duration(duration, direction) {
    if (duration) {
      if ((typeof duration === "undefined" ? "undefined" : _typeof(duration)) === 'object') {
        return duration[direction];
      } else {
        return duration;
      }
    } else {
      return defaultDuration;
    }
  }

  var expandTransitionComponent = {
    functional: true,
    props: ["duration"],
    render: function render(createElement, context) {
      var data = {
        props: {
          name: "expand",
          css: false
        },
        on: {
          beforeEnter: function beforeEnter(el) {
            el.style.height = 0;
            el.style.opacity = 0;
          },
          enter: function enter(el, done) {
            var elements = [].concat(_toConsumableArray(el.children));
            var height = elements.map(function (child) {
              return child.offsetHeight;
            }).reduce(function (sum, value) {
              return sum + value;
            }, 0);
            $(el).animate({ height: height, opacity: 1 }, duration(context.props.duration, 'enter'), function () {
              el.removeAttribute("style");
              done;
            });
          },
          leave: function leave(el, done) {
            $(el).animate({ height: 0, opacity: 0 }, duration(context.props.duration, 'leave'), function () {
              el.remove();
              done;
            });
          }
        }

      };
      return createElement('transition', data, context.children);
    }
  };
  return expandTransitionComponent;
}
"use strict";

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

function buildFadeTransition() {
  "use strict";

  var defaultDuration = 250;

  function duration(duration, direction) {
    if (duration) {
      if ((typeof duration === "undefined" ? "undefined" : _typeof(duration)) === 'object') {
        return duration[direction];
      } else {
        return duration;
      }
    } else {
      return defaultDuration;
    }
  }

  var fadeTransitionComponent = {
    functional: true,
    props: ["duration"],
    render: function render(createElement, context) {
      var data = {
        props: {
          name: "fade",
          css: false
        },
        on: {
          beforeEnter: function beforeEnter(el) {
            el.style.opacity = 0;
          },
          enter: function enter(el, done) {
            $(el).animate({ opacity: 1 }, duration(context.props.duration, 'enter'), function () {
              el.removeAttribute("style");
              done;
            });
          },
          leave: function leave(el, done) {
            $(el).animate({ opacity: 0 }, duration(context.props.duration, 'leave'), function () {
              el.remove();
              done;
            });
          }
        }

      };
      return createElement('transition', data, context.children);
    }
  };
  return fadeTransitionComponent;
}
"use strict";

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

(function () {
  "use strict";

  if ((typeof exports === "undefined" ? "undefined" : _typeof(exports)) == "object") {
    module.exports = {
      Expand: buildExpandTransition(),
      Fade: buildFadeTransition()
    };
  } else if (window && window.Vue) {
    var expandTransition = buildExpandTransition();
    Vue.component('expand-transition', expandTransition);

    var fadeTransition = buildFadeTransition();
    Vue.component('fade-transition', fadeTransition);
  }
})();
